@@ -24,7 +24,7 @@ def build_context(request, context={}):
     """
 
 
-    options = Options.get_options.get_options()
+    options = Options.manager.get_options()
     poll_flag = request.GET.get('poll_flag', None)
     mark_read_flag = request.GET.get('mark_read_flag', None)
     show_read_flag = request.GET.get('show_read_flag', None)
@@ -111,11 +111,7 @@ def poll_feed(db_feed, verbose=False):
     """
     Read through a feed looking for new entries.
     """
-    options = Options.objects.all()
-    if options:
-        options = options[0]
-    else:  # Create options row with default values
-        options = Options.objects.create()
+    options = Options.manager.get_options()
     parsed = feedparser.parse(db_feed.xml_url)
     if hasattr(parsed.feed, 'bozo_exception'):
         # Malformed feed
@@ -151,7 +147,7 @@ def poll_feed(db_feed, verbose=False):
     if verbose:
         print('%d entries to process in %s' % (len(parsed.entries), db_feed.title))
     for i, entry in enumerate(parsed.entries):
-        if i > options.max_entries_saved:
+        if i >= options.max_entries_saved:
             break
         missing_attr = False
         for attr in ['title', 'title_detail', 'link', 'description']:
@@ -165,9 +161,9 @@ def poll_feed(db_feed, verbose=False):
             continue
         if entry.title == "":
             msg = 'Feedreader poll_feeds. Entry "%s" has a blank title' % (entry.link)
-            logger.warning(msg)
             if verbose:
                 print(msg)
+            logger.warning(msg)
             continue
         db_entry, created = Entry.objects.get_or_create(feed=db_feed, link=entry.link)
         if created:
